==> haskell-time-compat-1.9.6.1-23-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-time-compat.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 time-compat
version:              1.9.6.1
visibility:           public
id:                   time-compat-1.9.6.1-DaB9lLz05fo2kr1gwenuv3
key:                  time-compat-1.9.6.1-DaB9lLz05fo2kr1gwenuv3
license:              BSD-3-Clause
maintainer:           Oleg Grenrus <oleg.grenrus@iki.fi>
author:               Ashley Yakeley
homepage:             https://github.com/haskellari/time-compat
synopsis:             Compatibility package for time
description:
    This packages tries to compat as much of @time@ features as possible.

    /TODO:/

    * Difference type @ParseTime@ and @FormatTime@ instances are missing.

    * Formatting varies depending on underlying @time@ version

    * @dayFractionToTimeOfDay@ on extreme values

category:             Time, Compatibility
abi:                  a3952d9bd33ce11ad5d6f0c48a73c36d
exposed:              True
exposed-modules:
    Data.Time.Calendar.Compat Data.Time.Calendar.Easter.Compat
    Data.Time.Calendar.Julian.Compat Data.Time.Calendar.Month.Compat
    Data.Time.Calendar.MonthDay.Compat
    Data.Time.Calendar.OrdinalDate.Compat
    Data.Time.Calendar.Quarter.Compat
    Data.Time.Calendar.WeekDate.Compat Data.Time.Clock.Compat
    Data.Time.Clock.POSIX.Compat Data.Time.Clock.System.Compat
    Data.Time.Clock.TAI.Compat Data.Time.Compat Data.Time.Format.Compat
    Data.Time.Format.ISO8601.Compat Data.Time.LocalTime.Compat

hidden-modules:
    Data.Format Data.Time.Calendar.Private Data.Time.Calendar.Types
    Data.Time.Orphans

import-dirs:          /usr/lib/ghc-9.0.2/site-local/time-compat-1.9.6.1
library-dirs:         /usr/lib/ghc-9.0.2/site-local/time-compat-1.9.6.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/x86_64-linux-ghc-9.0.2/time-compat-1.9.6.1
hs-libraries:         HStime-compat-1.9.6.1-DaB9lLz05fo2kr1gwenuv3
depends:
    base-4.15.1.0 base-orphans-0.8.6-58gtAdHVC823tbAP7RSB62
    deepseq-1.4.5.0 hashable-1.3.5.0-9wAI1WS8YgI32PWp14SUvr time-1.9.3

haddock-interfaces:   /usr/share/doc/haskell-time-compat/html/time-compat.haddock
haddock-html:         /usr/share/doc/haskell-time-compat/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-time-compat-1.9.6.1-25-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-time-compat.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 time-compat
version:              1.9.6.1
visibility:           public
id:                   time-compat-1.9.6.1-Dj453ay3fOL49SUR7SahvW
key:                  time-compat-1.9.6.1-Dj453ay3fOL49SUR7SahvW
license:              BSD-3-Clause
maintainer:           Oleg Grenrus <oleg.grenrus@iki.fi>
author:               Ashley Yakeley
homepage:             https://github.com/haskellari/time-compat
synopsis:             Compatibility package for time
description:
    This packages tries to compat as much of @time@ features as possible.

    /TODO:/

    * Difference type @ParseTime@ and @FormatTime@ instances are missing.

    * Formatting varies depending on underlying @time@ version

    * @dayFractionToTimeOfDay@ on extreme values

category:             Time, Compatibility
abi:                  486de17190bbe4031d5eef810280728d
exposed:              True
exposed-modules:
    Data.Time.Calendar.Compat Data.Time.Calendar.Easter.Compat
    Data.Time.Calendar.Julian.Compat Data.Time.Calendar.Month.Compat
    Data.Time.Calendar.MonthDay.Compat
    Data.Time.Calendar.OrdinalDate.Compat
    Data.Time.Calendar.Quarter.Compat
    Data.Time.Calendar.WeekDate.Compat Data.Time.Clock.Compat
    Data.Time.Clock.POSIX.Compat Data.Time.Clock.System.Compat
    Data.Time.Clock.TAI.Compat Data.Time.Compat Data.Time.Format.Compat
    Data.Time.Format.ISO8601.Compat Data.Time.LocalTime.Compat

hidden-modules:
    Data.Format Data.Time.Calendar.Private Data.Time.Calendar.Types
    Data.Time.Orphans

import-dirs:          /usr/lib/ghc-9.0.2/site-local/time-compat-1.9.6.1
library-dirs:         /usr/lib/ghc-9.0.2/site-local/time-compat-1.9.6.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/x86_64-linux-ghc-9.0.2/time-compat-1.9.6.1
hs-libraries:         HStime-compat-1.9.6.1-Dj453ay3fOL49SUR7SahvW
depends:
    base-4.15.1.0 base-orphans-0.8.6-INwJc044rMLKbu1Fc81fJ5
    deepseq-1.4.5.0 hashable-1.4.0.0-C2L4d9qsiUqGAQXABPs7JE time-1.9.3

haddock-interfaces:   /usr/share/doc/haskell-time-compat/html/time-compat.haddock
haddock-html:         /usr/share/doc/haskell-time-compat/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
